@@ -1,4 +1,5 @@
 from copy import copy
+import decimal
 import json
 import re
 import pytz
@@ -16,6 +17,7 @@ from django.utils.functional import Promise, SimpleLazyObject
 from django.utils.html import escape, mark_safe, format_html
 from django.middleware import csrf
 from django.template import loader as tpl_loader
+from django.contrib.admin import site
 
 try:
     from django.forms.models import ModelChoiceIteratorValue
@@ -29,10 +31,9 @@ from django.urls import (
     resolve, reverse, NoReverseMatch, get_resolver, get_ns_resolver, get_script_prefix
 )
 
+from . import models as djk_models
 from .utils import sdv
 from .utils.regex import finditer_with_separators
-from .models import model_fields_verbose_names
-from .admin import empty_value_display
 
 from djk_ui.tpl import (  # noqa: F401 imported but unused, used in Jinja2 templates
     print_bs_labels, print_bs_badges, print_bs_well, print_list_group, print_badge_list_group
@@ -414,7 +415,7 @@ def format_local_date(value, short_format=True, to_local_time=True, tz_name=None
         combined = datetime.combine(value, datetime.min.time())
         format = 'SHORT_DATE_FORMAT' if short_format else 'DATE_FORMAT'
     elif value is None:
-        return empty_value_display
+        return site.empty_value_display
     else:
         raise ValueError('Value must be instance of date or datetime')
     if timezone.is_aware(combined):
@@ -462,10 +463,8 @@ def resolve_cbv(viewname, urlconf=None, args=None, kwargs=None, current_app=None
         current_app = get_current_app(request)
     url = reverse(viewname, urlconf=urlconf, args=args, kwargs=kwargs, current_app=current_app)
     view_fn = resolve(url)[0]
-    if hasattr(view_fn, '__wrapped__'):
-        return sdv.get_cbv_from_dispatch_wrapper(view_fn)
-    else:
-        return view_fn
+    view_fn.view_initkwargs.update(kwargs)
+    return view_fn.view_class, view_fn.view_initkwargs
 
 
 def get_namespace_path_resolver(urlresolver, ns_path):
@@ -515,11 +514,14 @@ def get_formatted_url(url_name):
             raise NoReverseMatch('Multiple sprintf formatted url for %s' % url_name) from ex
 
 
+# See also validators.ViewmodelFormatting.json_serializable.
 class DjkJSONEncoder(DjangoJSONEncoder):
 
     def default(self, o):
         if isinstance(o, ModelChoiceIteratorValue):
             return o.value
+        if isinstance(o, decimal.Decimal):
+            return str(o)
         if isinstance(o, Promise):
             # force_str() is used because django.contrib.auth.models.User incorporates the instances of
             # django.utils.functional.lazy.<locals>.__proxy__ object, which are not JSON serializable.
@@ -531,8 +533,12 @@ class DjkJSONEncoder(DjangoJSONEncoder):
         return super().default(o)
 
 
-def to_json(self):
-    return json.dumps(self, ensure_ascii=False, cls=DjkJSONEncoder)
+def to_json(self, **kwargs):
+    return json.dumps(self, ensure_ascii=False, cls=DjkJSONEncoder, **kwargs)
+
+
+def pretty_json(self):
+    return to_json(self, sort_keys=True, indent=4)
 
 
 def json_flatatt(atts):
@@ -593,7 +599,7 @@ class ModelLinker:
             self.desc = None
         if self.desc is None:
             if self.str_fields is not None:
-                # todo: use models.model_fields_verbose_names() to optionally populate verbose (localized) list keys.
+                # todo: use model_fields_verbose_names() to optionally populate verbose (localized) list keys.
                 self.desc = print_list_group(self.str_fields)
             else:
                 if self.obj is not None:
@@ -607,7 +613,7 @@ class ModelLinker:
             nested_data['_strFields'] = self.str_fields
             nested_data['_options'] = {
                 'showKeys': True,
-                'i18n': model_fields_verbose_names(self.obj)
+                'i18n': djk_models.model_fields_verbose_names(self.obj)
             }
         return nested_data
 
@@ -621,7 +627,7 @@ class ModelLinker:
                 description=self.desc
             )
         else:
-            return empty_value_display if self.desc is None else self.desc
+            return site.empty_value_display if self.desc is None else self.desc
 
 
 class ContentTypeLinker(ModelLinker):
@@ -634,7 +640,7 @@ class ContentTypeLinker(ModelLinker):
         super().__init__(obj)
 
     def get_str_obj_type(self):
-        return str(empty_value_display if self.obj_type is None else self.obj_type)
+        return str(site.empty_value_display if self.obj_type is None else self.obj_type)
 
 
 # Resolve grid component view from the current request / grid view.
@@ -647,9 +653,17 @@ def resolve_grid(request, view_options):
     if 'pageRouteKwargs' in view_options:
         view_kwargs.update(view_options['pageRouteKwargs'])
     view_kwargs['action'] = ''
-    view_cls = resolve_cbv(viewname=view_options['pageRoute'], kwargs=view_kwargs, request=request)
-    return view_cls
+    view_cls, view_kwargs = resolve_cbv(viewname=view_options['pageRoute'], kwargs=view_kwargs, request=request)
+    return view_cls, view_kwargs
 
 
-def discover_grid_options(request, grid_options):
-    return resolve_grid(request, grid_options)().discover_grid_options(request, grid_options)
+def discover_grid_options(request, grid_options, extra_view_kwargs=None):
+    view_cls, view_kwargs = resolve_grid(request, grid_options)
+    if extra_view_kwargs is not None:
+        view_kwargs.update(extra_view_kwargs)
+    view = view_cls(**view_kwargs)
+    view_options = copy(grid_options)
+    if 'pageRouteKwargsKeys' in view_options:
+        del view_options['pageRouteKwargsKeys']
+        view_options['pageRouteKwargs'] = view_kwargs
+    return view.discover_grid_options(request, view_options)
