@@ -14,7 +14,7 @@ from django.db import models
 from django.views.generic.base import ContextMixin, TemplateResponseMixin, View
 from django.shortcuts import resolve_url
 from django.contrib.auth import REDIRECT_FIELD_NAME
-from django.contrib.contenttypes.models import ContentType
+from django.contrib import contenttypes
 
 from ..context_processors import create_page_context
 from .. import http
@@ -234,7 +234,13 @@ class ViewmodelView(TemplateResponseMixin, ContextMixin, View):
         if len(kwargs) > 0:
             vms = vm_list(dict(**kwargs))
         else:
-            vms = vm_list(*args)
+            if isinstance(args, dict):
+                vms = vm_list(*args)
+            else:
+                vms = vm_list(
+                    title=_('Error'),
+                    message=args,
+                )
         self.process_error_vm_list(vms)
         raise http.ImmediateJsonResponse(vms)
 
@@ -410,11 +416,14 @@ class BaseFilterView(PageContextMixin):
         self.grid_fields = None
         # Filtered names of grid_fields (no excluded field names)
         self.grid_fields_attnames = None
+        # Verbose names of fields
+        self.field_names = None
         self.allowed_sort_orders = None
         self.allowed_filter_fields = None
         self.search_fields = None
         self.has_get_str_fields = False
 
+    # yields flattened fields from possibly nested .grid_fields (optional compound columns)
     def yield_fields(self):
         for column in self.grid_fields:
             if isinstance(column, list):
@@ -424,11 +433,20 @@ class BaseFilterView(PageContextMixin):
                 yield column
 
     def yield_fields_attnames(self):
-        return [field[0] if isinstance(field, tuple) else field for field in self.yield_fields()]
+        for field_def in self.yield_fields():
+            if isinstance(field_def, dict):
+                yield field_def['field']
+            elif isinstance(field_def, tuple):
+                yield field_def[0]
+            else:
+                yield field_def
 
     def get_grid_fields_attnames(self):
         return [field for field in self.yield_fields_attnames() if field not in self.exclude_fields]
 
+    def set_grid_fields(self):
+        self.grid_fields_attnames = self.get_grid_fields_attnames()
+
     def has_grid_field(self, fieldname):
         return fieldname in self.get_grid_fields_attnames()
 
@@ -507,7 +525,7 @@ class BaseFilterView(PageContextMixin):
     def get_contenttype_filter(self, *apps_models):
         filter_choices = []
         for app_label, model in apps_models:
-            ct = ContentType.objects.filter(app_label=app_label, model=model).first()
+            ct = contenttypes.models.ContentType.objects.filter(app_label=app_label, model=model).first()
             filter_choices.append((ct.pk, ct.name))
         return filter_choices
 
@@ -560,16 +578,20 @@ class BaseFilterView(PageContextMixin):
                 )
 
         self.exclude_fields = self.get_exclude_fields()
-        self.grid_fields_attnames = self.get_grid_fields_attnames()
+        self.set_grid_fields()
         self.allowed_sort_orders = self.get_allowed_sort_orders()
         self.allowed_filter_fields = self.get_allowed_filter_fields()
         self.search_fields = self.get_search_fields()
+        self.field_names = {}
 
         self.has_get_str_fields = hasattr(self.model, 'get_str_fields')
 
     def get_field_verbose_name(self, field_name):
-        # str() is used to avoid "<django.utils.functional.__proxy__ object> is not JSON serializable" error.
-        return str(get_verbose_name(self.model, field_name))
+        if field_name in self.field_names:
+            return self.field_names[field_name]
+        else:
+            # str() is used to avoid "<django.utils.functional.__proxy__ object> is not JSON serializable" error.
+            return str(get_verbose_name(self.model, field_name))
 
     # Override in child class to customize output.
     def get_display_value(self, obj, field):
@@ -612,7 +634,7 @@ class BaseFilterView(PageContextMixin):
             if isinstance(canon_filter_def.get('choices'), (list, tuple)):
                 vm_filter['type'] = 'choices'
             else:
-                # Use App.ko.FkGridFilter to select filter choices.
+                # Use FkGridFilter to select filter choices.
                 # Autodetect widget.
                 field_validator = self.get_field_validator(fieldname)
                 vm_filter_autodetect = field_validator.detect_field_filter(canon_filter_def)
